@@ -3,6 +3,15 @@
 from typing import List, NamedTuple, Optional, Any
 
 
+class GatewayDevice(NamedTuple):
+    name: str
+    unique_id: str
+    data: dict
+    manufacturer: str
+    model: Optional[str]
+    sw_version: Optional[str]
+
+
 class ClimateDevice(NamedTuple):
     available: bool
     name: str
@@ -13,6 +22,7 @@ class ClimateDevice(NamedTuple):
     target_temperature: float
     max_temp: float
     min_temp: float
+    humidity: int
     hvac_mode: str
     hvac_action: str
     hvac_modes: List[str]
